@@ -5,11 +5,12 @@ import os
 import click
 
 from connect.cli.core.config import pass_config
-from connect.cli.plugins.project.extension_helpers import (
+from connect.cli.plugins.project.extension.helpers import (
     bootstrap_extension_project,
+    bump_runner_extension_project,
     validate_extension_project,
 )
-from connect.cli.plugins.project.report_helpers import (
+from connect.cli.plugins.project.report.helpers import (
     add_report,
     bootstrap_report_project,
     validate_report_project,
@@ -100,6 +101,7 @@ def grp_project_extension():
 )
 @pass_config
 def cmd_bootstrap_extension_project(config, output_dir):
+    config.validate()
     bootstrap_extension_project(config, output_dir)
 
 
@@ -117,5 +119,19 @@ def cmd_validate_extension_project(project_dir):
     validate_extension_project(project_dir)
 
 
+@grp_project_extension.command(
+    name='bump',
+    short_help='Update runner version to the latest one.',
+)
+@click.option(
+    '--project-dir', '-p',
+    required=True,
+    type=click.Path(exists=True, file_okay=False, dir_okay=True),
+    help='Project directory.',
+)
+def cmd_bump_extension_project(project_dir):
+    bump_runner_extension_project(project_dir)
+
+
 def get_group():
     return grp_project
